@@ -53,11 +53,10 @@ try:
     from mlflow import fastai
     from mlflow import gluon
     from mlflow import h2o
-    from mlflow import keras
     from mlflow import lightgbm
     from mlflow import mleap
     from mlflow import onnx
-    from mlflow import pipelines
+    from mlflow import recipes
     from mlflow import pyfunc
     from mlflow import pytorch
     from mlflow import sklearn
@@ -78,7 +77,6 @@ try:
         "fastai",
         "gluon",
         "h2o",
-        "keras",
         "lightgbm",
         "mleap",
         "onnx",
@@ -89,6 +87,7 @@ try:
         "spark",
         "statsmodels",
         "tensorflow",
+        "keras",
         "xgboost",
         "shap",
         "paddle",
@@ -104,9 +103,9 @@ except ImportError as e:
 
 _configure_mlflow_loggers(root_module_name=__name__)
 
-# TODO: Comment out this block when we deprecate support for python 3.7.
+# TODO: Comment out this block when we deprecate support for python 3.8.
 # _major = 3
-# _minor = 7
+# _minor = 8
 # _deprecated_version = (_major, _minor)
 # _min_supported_version = (_major, _minor + 1)
 
@@ -141,11 +140,9 @@ from mlflow.tracking.fluent import (
     start_run,
     end_run,
     search_runs,
-    list_run_infos,
     get_artifact_uri,
     get_experiment,
     get_experiment_by_name,
-    list_experiments,
     search_experiments,
     create_experiment,
     set_experiment,
@@ -171,6 +168,7 @@ from mlflow.models import evaluate
 from mlflow.client import MlflowClient
 from mlflow.exceptions import MlflowException
 from mlflow.projects import run
+from mlflow._doctor import doctor
 
 __all__ = [
     "ActiveRun",
@@ -199,7 +197,6 @@ __all__ = [
     "is_tracking_uri_set",
     "get_experiment",
     "get_experiment_by_name",
-    "list_experiments",
     "search_experiments",
     "create_experiment",
     "set_experiment",
@@ -210,10 +207,10 @@ __all__ = [
     "register_model",
     "get_registry_uri",
     "set_registry_uri",
-    "list_run_infos",
     "autolog",
     "evaluate",
     "last_active_run",
+    "doctor",
     "MlflowClient",
     "MlflowException",
 ] + _model_flavors_supported
