@@ -1,14 +1,14 @@
 class SourceType:
     """Enum for originating source of a :py:class:`mlflow.entities.Run`."""
 
-    NOTEBOOK, JOB, PROJECT, LOCAL, UNKNOWN, PIPELINE = range(1, 7)
+    NOTEBOOK, JOB, PROJECT, LOCAL, UNKNOWN, RECIPE = range(1, 7)
 
     _STRING_TO_SOURCETYPE = {
         "NOTEBOOK": NOTEBOOK,
         "JOB": JOB,
         "PROJECT": PROJECT,
         "LOCAL": LOCAL,
-        "PIPELINE": PIPELINE,
+        "PIPELINE": RECIPE,
         "UNKNOWN": UNKNOWN,
     }
     SOURCETYPE_TO_STRING = {value: key for key, value in _STRING_TO_SOURCETYPE.items()}
