@@ -4,7 +4,7 @@ The :py:mod:`mlflow.models.signature` module provides an API for specification o
 Model signature defines schema of model input and output. See :py:class:`mlflow.types.schema.Schema`
 for more details on Schema and data types.
 """
-from typing import Dict, Any, Union
+from typing import Dict, Any, Union, TYPE_CHECKING
 
 import pandas as pd
 import numpy as np
@@ -12,17 +12,19 @@ import numpy as np
 from mlflow.types.schema import Schema
 from mlflow.types.utils import _infer_schema
 
-try:
-    import pyspark.sql.dataframe
+# At runtime, we don't need  `pyspark.sql.dataframe`
+if TYPE_CHECKING:
+    try:
+        import pyspark.sql.dataframe
 
-    MlflowInferableDataset = Union[
-        pd.DataFrame, np.ndarray, Dict[str, np.ndarray], pyspark.sql.dataframe.DataFrame
-    ]
-except ImportError:
-    MlflowInferableDataset = Union[pd.DataFrame, np.ndarray, Dict[str, np.ndarray]]
+        MlflowInferableDataset = Union[
+            pd.DataFrame, np.ndarray, Dict[str, np.ndarray], pyspark.sql.dataframe.DataFrame
+        ]
+    except ImportError:
+        MlflowInferableDataset = Union[pd.DataFrame, np.ndarray, Dict[str, np.ndarray]]
 
 
-class ModelSignature(object):
+class ModelSignature:
     """
     ModelSignature specifies schema of model's inputs and outputs.
 
@@ -51,7 +53,7 @@ class ModelSignature(object):
         Input and output schema are represented as json strings. This is so that the
         representation is compact when embedded in a MLmofel yaml file.
 
-        :return: dictionary representation with input and output shcema represented as json strings.
+        :return: dictionary representation with input and output schema represented as json strings.
         """
 
         return {
@@ -94,7 +96,7 @@ class ModelSignature(object):
 
 
 def infer_signature(
-    model_input: Any, model_output: MlflowInferableDataset = None
+    model_input: Any, model_output: "MlflowInferableDataset" = None
 ) -> ModelSignature:
     """
     Infer an MLflow model signature from the training data (input) and model predictions (output).
