@@ -37,7 +37,8 @@ from mlflow.store.tracking import (
 )
 from mlflow.store.tracking.abstract_store import AbstractStore
 from mlflow.store.entities.paged_list import PagedList
-from mlflow.utils.name_utils import _generate_random_name
+from mlflow.utils import get_results_from_paginated_fn
+from mlflow.utils.name_utils import _generate_random_name, _generate_unique_integer_id
 from mlflow.utils.validation import (
     _validate_metric,
     _validate_metric_name,
@@ -48,7 +49,6 @@ from mlflow.utils.validation import (
     _validate_experiment_id,
     _validate_batch_log_limits,
     _validate_batch_log_data,
-    _validate_list_experiments_max_results,
     _validate_param_keys_unique,
     _validate_experiment_name,
 )
@@ -74,9 +74,9 @@ from mlflow.utils.file_utils import (
 )
 from mlflow.utils.search_utils import SearchUtils, SearchExperimentsUtils
 from mlflow.utils.string_utils import is_string_type
+from mlflow.utils.time_utils import get_current_time_millis
 from mlflow.utils.uri import append_to_uri_path
 from mlflow.utils.mlflow_tags import MLFLOW_LOGGED_MODELS, MLFLOW_RUN_NAME, _get_run_name_from_tags
-from mlflow.utils.time_utils import get_current_time_millis
 
 _TRACKING_DIR_ENV_VAR = "MLFLOW_TRACKING_DIR"
 
@@ -150,17 +150,20 @@ class FileStore(AbstractStore):
         self.trash_folder = os.path.join(self.root_directory, FileStore.TRASH_FOLDER_NAME)
         # Create root directory if needed
         if not exists(self.root_directory):
-            mkdir(self.root_directory)
-            self._create_experiment_with_id(
-                name=Experiment.DEFAULT_EXPERIMENT_NAME,
-                experiment_id=FileStore.DEFAULT_EXPERIMENT_ID,
-                artifact_uri=None,
-                tags=None,
-            )
+            self._create_default_experiment()
         # Create trash folder if needed
         if not exists(self.trash_folder):
             mkdir(self.trash_folder)
 
+    def _create_default_experiment(self):
+        mkdir(self.root_directory)
+        self._create_experiment_with_id(
+            name=Experiment.DEFAULT_EXPERIMENT_NAME,
+            experiment_id=FileStore.DEFAULT_EXPERIMENT_ID,
+            artifact_uri=None,
+            tags=None,
+        )
+
     def _check_root_dir(self):
         """
         Run checks before running directory operations.
@@ -240,53 +243,6 @@ class FileStore(AbstractStore):
     def _get_deleted_experiments(self, full_path=False):
         return list_subdirs(self.trash_folder, full_path)
 
-    def list_experiments(
-        self,
-        view_type=ViewType.ACTIVE_ONLY,
-        max_results=None,
-        page_token=None,
-    ):
-        """
-        :param view_type: Qualify requested type of experiments.
-        :param max_results: If passed, specifies the maximum number of experiments desired. If not
-                            passed, all experiments will be returned.
-        :param page_token: Token specifying the next page of results. It should be obtained from
-                           a ``list_experiments`` call.
-        :return: A :py:class:`PagedList <mlflow.store.entities.PagedList>` of
-                 :py:class:`Experiment <mlflow.entities.Experiment>` objects. The pagination token
-                 for the next page can be obtained via the ``token`` attribute of the object.
-        """
-        _validate_list_experiments_max_results(max_results)
-        self._check_root_dir()
-        rsl = []
-        if view_type == ViewType.ACTIVE_ONLY or view_type == ViewType.ALL:
-            rsl += self._get_active_experiments(full_path=False)
-        if view_type == ViewType.DELETED_ONLY or view_type == ViewType.ALL:
-            rsl += self._get_deleted_experiments(full_path=False)
-
-        experiments = []
-        for exp_id in rsl:
-            try:
-                # trap and warn known issues, will raise unexpected exceptions to caller
-                experiment = self._get_experiment(exp_id, view_type)
-                if experiment:
-                    experiments.append(experiment)
-            except MissingConfigException as rnfe:
-                # Trap malformed experiments and log warnings.
-                logging.warning(
-                    "Malformed experiment '%s'. Detailed error %s",
-                    str(exp_id),
-                    str(rnfe),
-                    exc_info=True,
-                )
-        if max_results is not None:
-            experiments, next_page_token = SearchUtils.paginate(
-                experiments, page_token, max_results
-            )
-            return PagedList(experiments, next_page_token)
-        else:
-            return PagedList(experiments, None)
-
     def search_experiments(
         self,
         view_type=ViewType.ACTIVE_ONLY,
@@ -320,20 +276,38 @@ class FileStore(AbstractStore):
         for exp_id in experiment_ids:
             try:
                 # trap and warn known issues, will raise unexpected exceptions to caller
-                experiments.append(self._get_experiment(exp_id, view_type))
+                exp = self._get_experiment(exp_id, view_type)
+                if exp is not None:
+                    experiments.append(exp)
             except MissingConfigException as e:
                 logging.warning(
                     f"Malformed experiment '{exp_id}'. Detailed error {e}", exc_info=True
                 )
         filtered = SearchExperimentsUtils.filter(experiments, filter_string)
         sorted_experiments = SearchExperimentsUtils.sort(
-            filtered, order_by or ["last_update_time DESC"]
+            filtered, order_by or ["creation_time DESC", "experiment_id ASC"]
         )
         experiments, next_page_token = SearchUtils.paginate(
             sorted_experiments, page_token, max_results
         )
         return PagedList(experiments, next_page_token)
 
+    def get_experiment_by_name(self, experiment_name):
+        def pagination_wrapper_func(number_to_get, next_page_token):
+            return self.search_experiments(
+                view_type=ViewType.ACTIVE_ONLY,
+                max_results=number_to_get,
+                filter_string=f"name = '{experiment_name}'",
+                page_token=next_page_token,
+            )
+
+        experiments = get_results_from_paginated_fn(
+            paginated_fn=pagination_wrapper_func,
+            max_results_per_page=SEARCH_MAX_RESULTS_THRESHOLD,
+            max_results=None,
+        )
+        return experiments[0] if len(experiments) > 0 else None
+
     def _create_experiment_with_id(self, name, experiment_id, artifact_uri, tags):
         artifact_uri = artifact_uri or append_to_uri_path(
             self.artifact_root_uri, str(experiment_id)
@@ -380,14 +354,7 @@ class FileStore(AbstractStore):
         self._check_root_dir()
         _validate_experiment_name(name)
         self._validate_experiment_does_not_exist(name)
-        # Get all existing experiments and find the one with largest numerical ID.
-        # len(list_all(..)) would not work when experiments are deleted.
-        experiments_ids = [
-            int(e.experiment_id)
-            for e in self.list_experiments(ViewType.ALL)
-            if e.experiment_id.isdigit()
-        ]
-        experiment_id = max(experiments_ids) + 1 if experiments_ids else 0
+        experiment_id = _generate_unique_integer_id()
         return self._create_experiment_with_id(name, str(experiment_id), artifact_location, tags)
 
     def _has_experiment(self, experiment_id):
@@ -438,6 +405,12 @@ class FileStore(AbstractStore):
         return experiment
 
     def delete_experiment(self, experiment_id):
+        if str(experiment_id) == str(FileStore.DEFAULT_EXPERIMENT_ID):
+            raise MlflowException(
+                "Cannot delete the default experiment "
+                f"'{FileStore.DEFAULT_EXPERIMENT_ID}'. This is an internally "
+                f"reserved experiment."
+            )
         experiment_dir = self._get_experiment_path(experiment_id, ViewType.ACTIVE_ONLY)
         if experiment_dir is None:
             raise MlflowException(
